@@ -1,4 +1,4 @@
-require 'spec_helper'
+# frozen_string_literal: true
 
 describe WPScan::Finders::Plugins::ConfigParser do
   xit
@@ -7,9 +7,9 @@ describe WPScan::Finders::Plugins::ConfigParser do
   #  subject(:finder) { described_class.new(target) }
   #  let(:target)     { WPScan::Target.new(url) }
   #  let(:url)        { 'http://wp.lab/' }
-  #  let(:fixtures)   { File.join(DYNAMIC_FINDERS_FIXTURES, 'plugin_version') }
+  #  let(:fixtures)   { DYNAMIC_FINDERS_FIXTURES.join('plugin_version') }
   #
   #  let(:expected_all) { df_expected_all['plugins'] }
-  #  let(:item_class)   { WPScan::Plugin }
+  #  let(:item_class)   { WPScan::Model::Plugin }
   # end
 end
